@@ -11,6 +11,34 @@
 #include <string.h>
 
 
+static void
+load_xcursor_theme (GConfClient *client)
+{
+  gchar *cursor_theme;
+  gint size;
+  char *add[] = { "xrdb", "-merge", NULL };
+  GString *add_string = g_string_new (NULL);
+
+  cursor_theme = gconf_client_get_string (client,
+					  "/desktop/gnome/peripherals/mouse/cursor_theme",
+					  NULL);
+  size = gconf_client_get_int (client,
+			       "/desktop/gnome/peripherals/mouse/cursor_size",
+			       NULL);
+  if (cursor_theme == NULL || size <= 0)
+    return;
+
+  g_string_append_printf (add_string,
+			  "Xcursor.theme: %s\n", cursor_theme);
+  g_string_append (add_string, "Xcursor.theme_core: true\n");
+  g_string_append_printf (add_string,
+			  "Xcursor.size: %d\n", size);
+
+  gnome_settings_daemon_spawn_with_input (add, add_string->str);
+
+  g_string_free (add_string, TRUE);
+}
+
 static void
 load_cursor (GConfClient *client)
 {
@@ -27,17 +55,17 @@ load_cursor (GConfClient *client)
   gchar *mkfontdir_cmd;
 
   /* setting up the dir */
-  font_dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome", NULL);
+  font_dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome2", NULL);
   if (! g_file_test (font_dir_name, G_FILE_TEST_EXISTS))
     mkdir (font_dir_name, 0755);
   g_free (font_dir_name);
   
-  font_dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome/share", NULL);
+  font_dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome2/share", NULL);
   if (! g_file_test (font_dir_name, G_FILE_TEST_EXISTS))
     mkdir (font_dir_name, 0755);
   g_free (font_dir_name);
 
-  font_dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome/share/fonts", NULL);
+  font_dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome2/share/fonts", NULL);
   if (! g_file_test (font_dir_name, G_FILE_TEST_EXISTS))
     mkdir (font_dir_name, 0755);
 
@@ -59,7 +87,7 @@ load_cursor (GConfClient *client)
       return;
     }
 
-  dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome/share/cursor-fonts", NULL);
+  dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome2/share/cursor-fonts", NULL);
   if (! g_file_test (dir_name, G_FILE_TEST_EXISTS))
     mkdir (dir_name, 0755);
 
@@ -122,7 +150,10 @@ load_cursor (GConfClient *client)
 
   /* run mkfontdir */
   mkfontdir_cmd = g_strdup_printf ("mkfontdir %s %s", dir_name, font_dir_name);
-  g_spawn_command_line_async (mkfontdir_cmd, NULL);
+  /* maybe check for error...
+   * also, it's not going to like that if there are spaces in dir_name/font_dir_name.
+   */
+  g_spawn_command_line_sync (mkfontdir_cmd, NULL, NULL, NULL, NULL);
   g_free (mkfontdir_cmd);
 
   /* Set the font path */
@@ -166,7 +197,8 @@ load_cursor (GConfClient *client)
 void
 gnome_settings_font_init (GConfClient *client)
 {
-  load_cursor (client);
+    load_xcursor_theme (client);
+    load_cursor (client);
 }
 
 void
